@@ -160,6 +160,11 @@ def classifier_gbdt(train_X, train_Y, test_X, threshold=0.5):
     return model, y_pred
 
 
+def classifier_model_evalution(y_eval, y_pred):
+    print('confusion_matrix:\n %s', confusion_matrix(y_eval, y_pred))
+    print('classification_report:\n %s', classification_report(y_eval, y_pred))
+
+
 def get_grouped_data(input_data, feature, target_col, bins, cuts=0):
     has_null = pd.isnull(input_data[feature]).sum() > 0
     if has_null == 1:
